@@ -270,7 +270,7 @@ class TaskRequestAssembler(Assembler):
             git_branch = None if dto.git_branch is None else UStr(dto.git_branch),
             task_type = None if dto.task_type is None else UStr(dto.task_type),
             task_template = None if dto.task_template is None else UStr(dto.task_template),
-            task_env = None if dto.task_env is None else UStr(dto.task_env),
+            task_env = None if dto.task_env is None else UDict(dto.task_env),
             task_command = None if dto.task_command is None else [UStr(m) for m in dto.task_command],
             task_arg = None if dto.task_arg is None else [UStr(m) for m in dto.task_arg],
             task_working_dir = None if dto.task_working_dir is None else UStr(dto.task_working_dir),
