@@ -270,7 +270,7 @@ class TaskRequestConverter(Converter):
             git_branch = None if do.git_branch is None else UStr(do.git_branch),
             task_type = None if do.task_type is None else UStr(do.task_type),
             task_template = None if do.task_template is None else UStr(do.task_template),
-            task_env = None if do.task_env is None else UStr(do.task_env),
+            task_env = None if do.task_env is None else UDict(do.task_env),
             task_command = None if do.task_command is None else [UStr(m) for m in do.task_command],
             task_arg = None if do.task_arg is None else [UStr(m) for m in do.task_arg],
             task_working_dir = None if do.task_working_dir is None else UStr(do.task_working_dir),
